"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.browserStorage = void 0;
var getStoredValue = function (storageType, key) {
    if (typeof window === 'undefined') {
        return undefined;
    }
    if (storageType === 'LOCAL') {
        var storedValue = localStorage.getItem(key) || '';
        return getObjectValue(storedValue);
    }
    if (storageType === 'SESSION') {
        var storedValue = sessionStorage.getItem(key);
        return getObjectValue(storedValue);
    }
    return;
};
var setValue = function (storageType, key, value) {
    if (typeof window === 'undefined') {
        return false;
    }
    if (storageType === 'LOCAL') {
        localStorage.setItem(key, JSON.stringify(value));
    }
    if (storageType === 'SESSION') {
        sessionStorage.setItem(key, JSON.stringify(value));
    }
    return true;
};
var clearValue = function (storageType, key) {
    if (typeof window === 'undefined') {
        return false;
    }
    if (storageType === 'LOCAL') {
        localStorage.removeItem(key);
    }
    if (storageType === 'SESSION') {
        sessionStorage.removeItem(key);
    }
    return true;
};
var getObjectValue = function (value) {
    if (value === null) {
        return null;
    }
    try {
        return JSON.parse(value);
    }
    catch (error) {
        return String(value);
    }
};
var browserStorage = { getStoredValue: getStoredValue, setValue: setValue, clearValue: clearValue };
exports.browserStorage = browserStorage;
